using System;
using System.IO;
using System.Text.Encodings.Web;
using System.Text.Unicode;
using Falcon.Extend;
using FAuth.DataBase;
using FAuth.Extensions;
using FAuth.Extensions.Account;
using FAuth.Extensions.Decryptor;
using Microsoft.AspNetCore.Builder;
using Microsoft.AspNetCore.Hosting;
using Microsoft.EntityFrameworkCore;
using Microsoft.Extensions.Caching.Redis;
using Microsoft.Extensions.Configuration;
using Microsoft.Extensions.DependencyInjection;
using Microsoft.Extensions.Hosting;
using Microsoft.OpenApi.Models;
using Microsoft.OpenApi.Writers;

namespace FAuth
{
    /// <summary>
    /// Ӧ
    /// </summary>
    public class Startup
    {
        public Startup(IConfiguration configuration) {
            Configuration = configuration;
        }

        public IConfiguration Configuration { get; }

        /// <summary>
        /// עᵽ
        /// </summary>
        /// <param name="services"></param>
        public void ConfigureServices(IServiceCollection services) {
            //עJsonл
            services.AddMsJsonProvider();
            //עݿ
            services.AddScoped<DbContext,FAuthDb>();
            services.AddDbContext<FAuthDb>(option => {
                var dbType = this.Configuration.GetValue<string>("Database:UseDb").ToLower();
                switch(dbType) {
                    case "mysql":
                        option.UseMySql(this.Configuration.GetValue<string>("Database:FAuthDbMySql"));
                        break;
                    case "sqlserver":
                        option.UseSqlServer(this.Configuration.GetValue<string>("Database:FAuthDbSqlServer"));
                        break;
                    default:
                        throw new Exception("Database:UseDbôֻΪmysqlsqlserver");
                }
            });
            services.AddAccountHelper();
            //עRedis
            var rop = this.Configuration.GetSection("Redis").Get<RedisCacheOptions>();
            services.AddRedis(rop);
            //עMVC
            services.AddControllersWithViews()
                .AddJsonOptions(option => {
                    option.JsonSerializerOptions.Encoder = JavaScriptEncoder.Create(UnicodeRanges.All);
                    option.JsonSerializerOptions.PropertyNamingPolicy = null;
                });

            //עSwagger
            services.AddSwaggerGen(c => {
                var option = this.Configuration.GetSection("SwaggerDoc");
                c.SwaggerDoc("V1",new OpenApiInfo {
                    Title = option.GetValue<string>("Title"),
                    Version = option.GetValue<string>("Version"),
                    Description = option.GetValue<string>("Description"),
                    Contact = new OpenApiContact {
                        Name = option.GetValue<string>("Contact:Name"),
                        Url = new Uri(option.GetValue<string>("Contact:Url")),
                    },
                });
                var xmlPath = Path.Combine(AppContext.BaseDirectory,typeof(Program).Assembly.GetName().Name + ".xml");
                c.IncludeXmlComments(xmlPath,true);
                c.AddXmlEnumEnable(xmlPath);
            });
            //עûƱ
            services.AddAESCrypto();
            var UTDO = Configuration.GetSection("UserTicketDecryptorOption");
            services.AddUserTicketDryptor(UTDO);
            //עapi
            services.AddScoped<ApiExceptionFilterAttribute>();
        }

        // This method gets called by the runtime. Use this method to configure the HTTP request pipeline.
        public void Configure(IApplicationBuilder app,IWebHostEnvironment env) {
            if(env.IsDevelopment()) {
                app.UseDeveloperExceptionPage();
            } else {
                app.UseExceptionHandler("/Home/Error");
                // The default HSTS value is 30 days. You may want to change this for production scenarios, see https://aka.ms/aspnetcore-hsts.
                app.UseHsts();
            }

            using(var socpe = app.ApplicationServices.CreateScope()) {
                var db = socpe.ServiceProvider.GetService<FAuthDb>();
                db.InitSync().Wait();
            }

            app.UseHttpsRedirection();
            app.UseStaticFiles();

            app.UseRouting();

            app.UseSwagger();
            app.UseSwaggerUI(c => {
                c.SwaggerEndpoint("/swagger/V1/swagger.json","ӿĵ");
                c.RoutePrefix = "";
            });

            app.UseAuthorization();

            app.UseEndpoints(endpoints => {
                endpoints.MapControllerRoute(
                    name: "default",
                    pattern: "{controller=Home}/{action=Index}/{id?}");
            });
        }
    }
}
